app_intents_annotations library

The app_intents_annotations

Classes

AppSchemas
A curated, verified catalog of App Schema identifiers, grouped by domain.
AppShortcut
App Shortcutを定義するためのアノテーション
AppShortcutsProvider
AppShortcutsProviderを定義するクラスに付与するアノテーション
EntityDefaultQuery
Annotations for marking entity parameters in intent specifications.
EntityId
Annotations for marking entity parameters in intent specifications.
EntityImage
Annotations for marking entity parameters in intent specifications.
EntityProperty
Marks an entity field to be exposed to the system as a Swift @Property.
EntitySpec
Annotation to specify an entity with its metadata.
EntitySpecBase<M>
Base class for entity specifications.
EntitySubtitle
Annotations for marking entity parameters in intent specifications.
EntityTitle
Annotations for marking entity parameters in intent specifications.
EnumCaseDisplay
Annotation to customize the display title of an enum case.
EnumSpec
Annotation to define an AppEnum for use in App Intents.
IntentFile
Represents a file received from an App Intent parameter.
IntentParam
Annotation to describe a parameter of an app intent.
IntentSpec
Annotation to specify an app intent.
IntentSpecBase
Base class for defining intent specifications.
MailSchemas
Verified schemas in the mail domain.
MessagesSchemas
Verified schemas in the messages domain.
PersonName
A structured personal name received from (or passed to) an App Intent parameter.
PhotosSchemas
Verified schemas in the photos domain.
UnionCase
Marks a subclass of a UnionValueSpec sealed class as one union case.
UnionValueSpec
Marks a sealed Dart class as a WWDC26 App Intents union value (#53).

Enums

AppSchemaDomain
The known App Schema domains (the namespace before the dot, e.g. messages in messages.message).
EntityExportType
The system structured type an entity can be exported as for cross-app sharing (#54).
EntityOwnershipState
The ownership state of an entity.
IntentExecutionTarget
A target process an intent is allowed to execute in.
IntentImplementation
The implementation language for the intent.
IntentMode
Defines the execution mode for an App Intent.