IntentMode enum

Defines the execution mode for an App Intent.

Maps to iOS 26+ IntentModes (supportedModes property). For iOS < 26, the equivalent openAppWhenRun property is also generated.

Inheritance
Available extensions

Values

background → const IntentMode

The intent runs in the background without opening the app (default).

foreground → const IntentMode

The app opens in the foreground when the intent runs.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<IntentMode>
A constant List of the values in this enum, in order of their declaration.