MessagesSchemas class final

Verified schemas in the messages domain.

Properties

editSentMessage String
messages.editSentMessage — edit a sent message (@AppIntent).
no setter
hashCode int
The hash code for this object.
no setterinherited
message String
messages.message — a message entity (@AppEntity).
no setter
messageAttribute String
messages.messageAttribute — message attribute (@AppEnum).
no setter
messageEffect String
messages.messageEffect — message effect (@AppEnum).
no setter
messagePerson String
messages.messagePerson — a message participant entity (@AppEntity).
no setter
messageType String
messages.messageType — message type (@AppEnum).
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sendMessage String
messages.sendMessage — send a message (@AppIntent).
no setter
setMessageReadStatus String
messages.setMessageReadStatus — set read status (@AppIntent).
no setter
unsendMessage String
messages.unsendMessage — unsend a sent message (@AppIntent).
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited