app_intents_annotations library
The app_intents_annotations
Classes
- AppShortcut
- App Shortcutを定義するためのアノテーション
- AppShortcutsProvider
- AppShortcutsProviderを定義するクラスに付与するアノテーション
- EntityDefaultQuery
- Annotations for marking entity parameters in intent specifications.
- EntityId
- Annotations for marking entity parameters in intent specifications.
- EntityImage
- Annotations for marking entity parameters in intent specifications.
- EntitySpec
- Annotation to specify an entity with its metadata.
-
EntitySpecBase<
M> - Base class for entity specifications.
- EntitySubtitle
- Annotations for marking entity parameters in intent specifications.
- EntityTitle
- Annotations for marking entity parameters in intent specifications.
- EnumCaseDisplay
- Annotation to customize the display title of an enum case.
- EnumSpec
- Annotation to define an AppEnum for use in App Intents.
- IntentFile
- Represents a file received from an App Intent parameter.
- IntentParam
- Annotation to describe a parameter of an app intent.
- IntentSpec
- Annotation to specify an app intent.
- IntentSpecBase
- Base class for defining intent specifications.
Enums
- IntentImplementation
- The implementation language for the intent.
- IntentMode
- Defines the execution mode for an App Intent.