EntitySpec class
Annotation to specify an entity with its metadata.
Constructors
Properties
- description → String?
-
An optional description of the entity.
final
- displayImageName → String?
-
Optional asset image name for entity display representation.
final
- enumerable → bool
-
Whether to generate
EnumerableEntityQueryconformance.final - hashCode → int
-
The hash code for this object.
no setterinherited
- identifier → String
-
A unique identifier for the entity.
final
- indexed → bool
-
Whether to generate
IndexedEntityconformance for Spotlight search.final - pluralTitle → String
-
A human-readable plural title for the entity.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
A human-readable title for the entity.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited